export function stringToBoolean(value, defaultValue = false) {
    if (value == null || typeof value !== "string")
        return defaultValue;
    return ["1", "true", "yes"].includes(value.toLocaleLowerCase());
}
export function stringToInteger(value, defaultValue = 0) {
    var _a;
    if (value == null || typeof value !== "string")
        return defaultValue;
    return (_a = parseInt(value.trim(), 10)) !== null && _a !== void 0 ? _a : defaultValue;
}
export function stringToFloat(value, defaultValue = 0.0) {
    var _a;
    if (value == null || typeof value !== "string")
        return defaultValue;
    return (_a = parseFloat(value.trim())) !== null && _a !== void 0 ? _a : defaultValue;
}
export function valueToBoolean(value, defaultValue = false) {
    if (value == null)
        return defaultValue;
    if (typeof value === "boolean")
        return value;
    if (typeof value === "number")
        return value !== 0;
    return ["1", "true", "yes"].includes(value.toString().toLocaleLowerCase());
}
export function valueToInteger(value, defaultValue = 0) {
    var _a;
    if (value == null)
        return defaultValue;
    if (typeof value === "boolean")
        return value ? 1 : 0;
    if (typeof value === "number")
        return Math.floor(value);
    return (_a = parseInt(value.toString().trim(), 10)) !== null && _a !== void 0 ? _a : defaultValue;
}
export function valueToFloat(value, defaultValue = 0.0) {
    var _a;
    if (value == null)
        return defaultValue;
    if (typeof value === "boolean")
        return value ? 1 : 0;
    if (typeof value === "number")
        return Math.floor(value);
    return (_a = parseFloat(value.toString().trim())) !== null && _a !== void 0 ? _a : defaultValue;
}
export function valueToString(value, defaultValue = "") {
    var _a;
    if (value == null)
        return defaultValue;
    // if (value == "") return defaultValue // ???
    return (_a = value.toString()) !== null && _a !== void 0 ? _a : defaultValue;
}
// export function mapToObject<T>(map: Map<string, T>): { [key: string]: T } {
//   return Object.fromEntries(map)
// }
// export function objectToMap<T>(obj: { [key: string]: T }): Map<string, T> {
//   return new Map(Object.entries(obj))
// }
// Shortcuts
export const toFloat = valueToFloat;
export const toInt = valueToInteger;
export const toString = valueToString;
export const toBool = valueToBoolean;
function serializer(replacer, cycleReplacer) {
    var stack = [], keys = [];
    if (cycleReplacer == null)
        cycleReplacer = function (key, value) {
            if (stack[0] === value)
                return "[Circular ~]";
            return ("[Circular ~." + keys.slice(0, stack.indexOf(value)).join(".") + "]");
        };
    return function (key, value) {
        if (stack.length > 0) {
            var thisPos = stack.indexOf(this);
            ~thisPos ? stack.splice(thisPos + 1) : stack.push(this);
            ~thisPos ? keys.splice(thisPos, Infinity, key) : keys.push(key);
            if (~stack.indexOf(value))
                value = cycleReplacer === null || cycleReplacer === void 0 ? void 0 : cycleReplacer.call(this, key, value);
        }
        else
            stack.push(value);
        return replacer == null ? value : replacer.call(this, key, value);
    };
}
export function stringify(obj, replacer, spaces, cycleReplacer) {
    // @ts-ignore
    return JSON.stringify(obj, serializer(replacer, cycleReplacer), spaces);
}
export function formatMessages(messages, opt = {}) {
    const { trace = true, pretty = true } = opt;
    return messages.map((obj) => {
        if (obj && typeof obj === "object") {
            if (obj instanceof Error) {
                if (!trace) {
                    return `${obj.name || "Error"}: ${obj.message}`;
                }
                return `${obj.name || "Error"}: ${obj.message}\n${obj.stack}`;
            }
            return pretty ? stringify(obj, null, 2) : stringify(obj);
        }
        return String(obj);
    });
}
export function renderMessages(messages, opt = {}) {
    return formatMessages(messages, opt).join(" ");
}
//# sourceMappingURL=convert.js.map